@@ -23,14 +23,10 @@ function y=modulo(x,N);
 %  along with this program; if not, write to the Free Software
 %  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-L=length(x);
-
-for l=1:L,
-  if rem(x(l),N)==0,
-    y(l)=N;
-  elseif rem(x(l),N)<0,
-    y(l)=rem(x(l),N)+N;
-  else
-    y(l)=rem(x(l),N);
-  end
-end
+if isreal(x)
+  y=mod(x,N);
+  idx=find(y==0);
+  y(idx)=N;
+else
+  y=mod(real(x),N)+i*mod(imag(x),N);
+end;
