@@ -1,4 +1,4 @@
-#!/bin/perl
+#!/usr/bin/perl
 
 #-------------------------------------------------
 #
@@ -9,7 +9,7 @@
 
 use strict;
 
-my $tftb_root = "/tftb_octave_matlab/tests";
+my $tftb_root = "../tests";
 @ARGV = "$tftb_root";
 
 my $dir = $ARGV[0];
@@ -57,7 +57,7 @@ sub ListRep {
 		print FILE "NAME OF THE FILE : $_\n";
         	close (FILE); 
 		
-		system( "octave --silent $tftb_root/$_  2>> error.log");
+		system( "octave -q -p ../mfiles $tftb_root/$_  2>> error.log");
 		 	
 		}
 		else {
